@@ -1,6 +1,6 @@
 package Test::Mocha::Util;
 {
-  $Test::Mocha::Util::VERSION = '0.21_01';
+  $Test::Mocha::Util::VERSION = '0.21_02';
 }
 # ABSTRACT: Internal utility functions
 
@@ -37,8 +37,10 @@ sub getattr {
     my ($object, $attribute) = @_;
 
     # uncoverable branch true
+    confess "getattr() must be given an object"
+        if not ref $object;
     confess "Attribute '$attribute' does not exist for object '$object'"
-        if not defined $object->{$attribute};
+        if not exists $object->{$attribute};
 
     return $object->{$attribute};
 }
